import { Injectable } from '@angular/core';
import { Http, Headers, RequestOptions, Response } from '@angular/http';
import 'rxjs/Rx';
import { Observable } from 'rxjs/Rx';

@Injectable()
export class AppService {

   
    chartDataApi: string = "http://nodejs.infragistics.com/api";
    detailsDataApi: string = "http://nodejs.infragistics.com/api/details";
    gridDataApi: string = "http://nodejs.infragistics.com/api/griddata";

    constructor(private _http: Http) { }

    // fetch stock data from the REST API 
    // Learn more about angular server communication : https://angular.io/docs/ts/latest/guide/server-communication.html

    getStocks() {
        let data = this._http.get(this.chartDataApi).map(this.extractData).catch(this.handleError);
        return data;
    }

    getDetails() {

        let data = this._http.get(this.detailsDataApi).map(this.extractData).catch(this.handleError);
        return data;

    }

    getGridData() {
        let data = this._http.get(this.gridDataApi).map(this.extractData).catch(this.handleError);
        return data;

    }

    getVolumeChartData() {

        var data = this.volumeChartData();
        return data;
    }


    // to extract JSON from server response 
    private extractData(res: Response) {
        let body = res.json();
        return body || {};
    }

    // to handle error in server communication 
    private handleError(error: any) {
        let errMsg = (error.message) ? error.message :
            error.status ? `${error.status} - ${error.statusText}` : 'Server error';
        console.error(errMsg);
        return Observable.throw(errMsg);
    }



    private volumeChartData() {
        return [{ "Close": 23.377, "Date": "2017-02-02T06:59:39.254Z", "High": 23.84, "Low": 23.2919, "Open": 23.82, "Volume": "25957711" }, { "Close": 23.1987, "Date": "2017-02-01T06:59:39.254Z", "High": 23.45937, "Low": 23.182, "Open": 23.2313, "Volume": "37273270" }, { "Close": 23.2528, "Date": "2017-01-31T06:59:39.254Z", "High": 23.661, "Low": 23.144, "Open": 23.553, "Volume": "15471280" }, { "Close": 23.0863, "Date": "2017-01-30T06:59:39.254Z", "High": 23.53824, "Low": 23.08, "Open": 23.12478, "Volume": "37754101" }, { "Close": 23.208, "Date": "2017-01-29T06:59:39.254Z", "High": 23.27, "Low": 23.115, "Open": 23.24, "Volume": "21208522" }, { "Close": 22.8358, "Date": "2017-01-26T06:59:39.254Z", "High": 23.072, "Low": 22.73, "Open": 22.975865, "Volume": "32701736" }, { "Close": 22.875, "Date": "2017-01-25T06:59:39.254Z", "High": 23.1, "Low": 22.609, "Open": 23.08481, "Volume": "39376379" }, { "Close": 22.618067, "Date": "2017-01-24T06:59:39.254Z", "High": 23.003064, "Low": 22.5284, "Open": 22.8777, "Volume": "37958091" }, { "Close": 22.48, "Date": "2017-01-23T06:59:39.254Z", "High": 22.9526, "Low": 22.449373, "Open": 22.789, "Volume": "36062302" }, { "Close": 22.499, "Date": "2017-01-22T06:59:39.254Z", "High": 22.799466, "Low": 22.429, "Open": 22.523, "Volume": "42959783" }, { "Close": 22.1955, "Date": "2017-01-19T06:59:39.254Z", "High": 22.60216, "Low": 22.12297, "Open": 22.47743, "Volume": "33993104" }, { "Close": 22.03357, "Date": "2017-01-18T06:59:39.254Z", "High": 22.617593, "Low": 22.023762, "Open": 22.09, "Volume": "19482217" }, { "Close": 21.9605, "Date": "2017-01-17T06:59:39.254Z", "High": 22.28, "Low": 21.944, "Open": 21.97112, "Volume": "21579625" }, { "Close": 22.1238, "Date": "2017-01-16T06:59:39.254Z", "High": 22.43, "Low": 21.8576, "Open": 22.278, "Volume": "25199352" }, { "Close": 22.161, "Date": "2017-01-15T06:59:39.254Z", "High": 22.366, "Low": 21.9659, "Open": 22.27, "Volume": "28213403" }, { "Close": 21.81, "Date": "2017-01-12T06:59:39.254Z", "High": 21.9873, "Low": 21.558909, "Open": 21.983, "Volume": "35056317" }, { "Close": 21.473, "Date": "2017-01-11T06:59:39.254Z", "High": 21.943, "Low": 21.467, "Open": 21.649392, "Volume": "27669402" }, { "Close": 21.3664, "Date": "2017-01-10T06:59:39.254Z", "High": 21.43786, "Low": 21.352, "Open": 21.3865, "Volume": "29746876" }, { "Close": 21.381854, "Date": "2017-01-09T06:59:39.254Z", "High": 21.8249, "Low": 21.277647, "Open": 21.56772, "Volume": "15110885" }, { "Close": 21.3385, "Date": "2017-01-08T06:59:39.254Z", "High": 21.753, "Low": 21.206, "Open": 21.465081, "Volume": "26832394" }, { "Close": 21.221, "Date": "2017-01-05T06:59:39.254Z", "High": 21.4413, "Low": 20.948063, "Open": 21.43, "Volume": "37810175" }, { "Close": 20.9161, "Date": "2017-01-04T06:59:39.254Z", "High": 20.98, "Low": 20.86, "Open": 20.92323, "Volume": "42405507" }, { "Close": 20.83761, "Date": "2017-01-03T06:59:39.254Z", "High": 20.999, "Low": 20.8, "Open": 20.96, "Volume": "20965652" }, { "Close": 20.7343, "Date": "2017-01-02T06:59:39.254Z", "High": 20.874, "Low": 20.7144, "Open": 20.7436, "Volume": "29716291" }, { "Close": 20.6297, "Date": "2017-01-01T06:59:39.254Z", "High": 21.19, "Low": 20.62, "Open": 21.067642, "Volume": "28348397" }, { "Close": 20.96, "Date": "2016-12-29T06:59:39.254Z", "High": 21.6608, "Low": 20.82, "Open": 21.53442, "Volume": "33697745" }, { "Close": 21.2457, "Date": "2016-12-28T06:59:39.254Z", "High": 21.838774, "Low": 21.0611, "Open": 21.70511, "Volume": "37914654" }, { "Close": 21.27989, "Date": "2016-12-27T06:59:39.254Z", "High": 21.637, "Low": 21, "Open": 21.286334, "Volume": "41027614" }, { "Close": 21.021, "Date": "2016-12-26T06:59:39.254Z", "High": 21.548, "Low": 21.013116, "Open": 21.02308, "Volume": "43450059" }, { "Close": 21.1323, "Date": "2016-12-25T06:59:39.254Z", "High": 22.147613, "Low": 21.1269, "Open": 21.155316, "Volume": "31264949" }, { "Close": 21.387, "Date": "2016-12-22T06:59:39.254Z", "High": 22.28, "Low": 21.32896, "Open": 21.5232, "Volume": "25657433" }, { "Close": 21.892, "Date": "2016-12-21T06:59:39.254Z", "High": 22.40413, "Low": 21.5481, "Open": 22.334, "Volume": "17482829" }, { "Close": 22.12641, "Date": "2016-12-20T06:59:39.254Z", "High": 22.4776, "Low": 21.528, "Open": 22.421378, "Volume": "29355466" }, { "Close": 22.344991, "Date": "2016-12-19T06:59:39.254Z", "High": 22.54, "Low": 21.647, "Open": 22.5, "Volume": "19836346" }, { "Close": 21.7101, "Date": "2016-12-18T06:59:39.254Z", "High": 22.18, "Low": 21.7, "Open": 21.8741, "Volume": "28292150" }, { "Close": 22.4925, "Date": "2016-12-15T06:59:39.254Z", "High": 22.644, "Low": 21.967, "Open": 22.556, "Volume": "32654928" }, { "Close": 22.55315, "Date": "2016-12-14T06:59:39.254Z", "High": 22.963, "Low": 22.0368, "Open": 22.93766, "Volume": "26444673" }, { "Close": 22.105, "Date": "2016-12-13T06:59:39.254Z", "High": 23.1218, "Low": 22.0688, "Open": 22.489, "Volume": "23988666" }, { "Close": 22.64191, "Date": "2016-12-12T06:59:39.254Z", "High": 23.28237, "Low": 22.2168, "Open": 22.833, "Volume": "18606854" }, { "Close": 22.943, "Date": "2016-12-11T06:59:39.254Z", "High": 23.083, "Low": 22.60144, "Open": 22.974727, "Volume": "32780944" }, { "Close": 23.533, "Date": "2016-12-08T06:59:39.254Z", "High": 23.6102, "Low": 22.75, "Open": 23.59561, "Volume": "24333250" }, { "Close": 22.704, "Date": "2016-12-07T06:59:39.254Z", "High": 23.39, "Low": 22.5645, "Open": 23.07, "Volume": "38928967" }, { "Close": 22.681282, "Date": "2016-12-06T06:59:39.254Z", "High": 23.6911, "Low": 22.63767, "Open": 23.5398, "Volume": "26729487" }, { "Close": 22.72401, "Date": "2016-12-05T06:59:39.254Z", "High": 23.718916, "Low": 22.709338, "Open": 22.76, "Volume": "19440977" }, { "Close": 22.86877, "Date": "2016-12-04T06:59:39.254Z", "High": 23.207, "Low": 22.80434, "Open": 22.883088, "Volume": "40443139" }, { "Close": 23.15974, "Date": "2016-12-01T06:59:39.254Z", "High": 23.51232, "Low": 23.129949, "Open": 23.50839, "Volume": "22989598" }, { "Close": 23.198, "Date": "2016-11-30T06:59:39.254Z", "High": 23.699, "Low": 23.167, "Open": 23.57122, "Volume": "28275645" }, { "Close": 23.069, "Date": "2016-11-29T06:59:39.254Z", "High": 24.052465, "Low": 23.046314, "Open": 23.6778, "Volume": "43353543" }, { "Close": 23.4424, "Date": "2016-11-28T06:59:39.254Z", "High": 23.747, "Low": 23.023507, "Open": 23.72991, "Volume": "26272577" }, { "Close": 23.571908, "Date": "2016-11-27T06:59:39.254Z", "High": 23.9523, "Low": 22.987, "Open": 23.8504, "Volume": "28629820" }, { "Close": 22.9, "Date": "2016-11-24T06:59:39.254Z", "High": 23.781, "Low": 22.9, "Open": 23.3362, "Volume": "30957270" }, { "Close": 23.046, "Date": "2016-11-23T06:59:39.254Z", "High": 23.31, "Low": 22.8602, "Open": 23.22347, "Volume": "44073379" }, { "Close": 22.89777, "Date": "2016-11-22T06:59:39.254Z", "High": 23.512, "Low": 22.84, "Open": 23.2487, "Volume": "19366483" }, { "Close": 23.308, "Date": "2016-11-21T06:59:39.254Z", "High": 23.53, "Low": 23.037, "Open": 23.45, "Volume": "29082090" }, { "Close": 22.94746, "Date": "2016-11-20T06:59:39.254Z", "High": 23.68, "Low": 22.766, "Open": 23.60366, "Volume": "35838249" }, { "Close": 22.7212, "Date": "2016-11-17T06:59:39.254Z", "High": 23.54493, "Low": 22.66, "Open": 22.74008, "Volume": "42560841" }, { "Close": 23.366, "Date": "2016-11-16T06:59:39.254Z", "High": 23.541, "Low": 22.64, "Open": 23.46, "Volume": "26450775" }, { "Close": 22.60647, "Date": "2016-11-15T06:59:39.254Z", "High": 23.0993, "Low": 22.596, "Open": 22.8943, "Volume": "22518853" }, { "Close": 22.60628, "Date": "2016-11-14T06:59:39.254Z", "High": 23.387173, "Low": 22.5644, "Open": 22.95, "Volume": "19168256" }, { "Close": 22.548513, "Date": "2016-11-13T06:59:39.254Z", "High": 22.821615, "Low": 22.529634, "Open": 22.8026, "Volume": "25665794" }, { "Close": 23.02122, "Date": "2016-11-10T06:59:39.254Z", "High": 23.13438, "Low": 22.896, "Open": 23.115, "Volume": "24828728" }, { "Close": 22.415952, "Date": "2016-11-09T06:59:39.254Z", "High": 23.42, "Low": 22.3939, "Open": 22.685697, "Volume": "21751376" }, { "Close": 22.44958, "Date": "2016-11-08T06:59:39.254Z", "High": 23.184195, "Low": 22.3657, "Open": 22.88, "Volume": "38883587" }, { "Close": 22.3196, "Date": "2016-11-07T06:59:39.254Z", "High": 23.2012, "Low": 22.31916, "Open": 22.790095, "Volume": "41630444" }, { "Close": 22.2941, "Date": "2016-11-06T06:59:39.254Z", "High": 22.68151, "Low": 22.29, "Open": 22.3349, "Volume": "17437658" }, { "Close": 22.20575, "Date": "2016-11-03T06:59:39.254Z", "High": 22.6858, "Low": 22.20113, "Open": 22.21, "Volume": "29730872" }, { "Close": 22.316, "Date": "2016-11-02T06:59:39.254Z", "High": 22.788, "Low": 22.18, "Open": 22.55924, "Volume": "41774387" }, { "Close": 22.353, "Date": "2016-11-01T06:59:39.254Z", "High": 23.112, "Low": 22.13231, "Open": 22.9427, "Volume": "36019451" }, { "Close": 22.21788, "Date": "2016-10-31T06:59:39.254Z", "High": 22.21879, "Low": 22.217, "Open": 22.218103, "Volume": "30661965" }, { "Close": 22.293, "Date": "2016-10-30T06:59:39.254Z", "High": 22.31637, "Low": 22.23782, "Open": 22.316, "Volume": "24664177" }, { "Close": 22.60732, "Date": "2016-10-27T06:59:39.254Z", "High": 22.61, "Low": 22.606225, "Open": 22.608024, "Volume": "21595185" }, { "Close": 22.6365, "Date": "2016-10-26T06:59:39.254Z", "High": 22.702833, "Low": 22.6121, "Open": 22.639, "Volume": "15141243" }, { "Close": 22.8, "Date": "2016-10-25T06:59:39.254Z", "High": 22.801, "Low": 22.717, "Open": 22.8, "Volume": "25704052" }, { "Close": 22.897897, "Date": "2016-10-24T06:59:39.254Z", "High": 22.8983, "Low": 22.8504, "Open": 22.898, "Volume": "28831984" }, { "Close": 22.99467, "Date": "2016-10-23T06:59:39.254Z", "High": 22.9954, "Low": 22.9944, "Open": 22.995, "Volume": "44848066" }, { "Close": 23.2855, "Date": "2016-10-20T06:59:39.254Z", "High": 23.29, "Low": 23.28538, "Open": 23.287589, "Volume": "30588152" }, { "Close": 23.38359, "Date": "2016-10-19T06:59:39.254Z", "High": 23.3849, "Low": 23.3302, "Open": 23.38421, "Volume": "34032516" }, { "Close": 23.4799, "Date": "2016-10-18T06:59:39.254Z", "High": 23.482, "Low": 23.402, "Open": 23.482, "Volume": "40754279" }, { "Close": 23.5765, "Date": "2016-10-17T06:59:39.254Z", "High": 23.58, "Low": 23.499323, "Open": 23.58, "Volume": "36489301" }, { "Close": 23.67444, "Date": "2016-10-16T06:59:39.254Z", "High": 23.676, "Low": 23.581, "Open": 23.675425, "Volume": "36738382" }, { "Close": 23.96243, "Date": "2016-10-13T06:59:39.254Z", "High": 23.97, "Low": 23.94, "Open": 23.97, "Volume": "30670100" }, { "Close": 24.06209, "Date": "2016-10-12T06:59:39.254Z", "High": 24.064, "Low": 24.0084, "Open": 24.06354, "Volume": "36088359" }, { "Close": 24.1606, "Date": "2016-10-11T06:59:39.254Z", "High": 24.162, "Low": 24.16, "Open": 24.1611, "Volume": "39344341" }, { "Close": 24.256474, "Date": "2016-10-10T06:59:39.254Z", "High": 24.26, "Low": 24.23, "Open": 24.2588, "Volume": "16624108" }, { "Close": 24.29, "Date": "2016-10-09T06:59:39.254Z", "High": 24.3555, "Low": 24.2893, "Open": 24.35403, "Volume": "22678955" }, { "Close": 24.644786, "Date": "2016-10-06T06:59:39.254Z", "High": 24.646, "Low": 24.57, "Open": 24.646, "Volume": "30120624" }, { "Close": 24.7433, "Date": "2016-10-05T06:59:39.254Z", "High": 24.7444, "Low": 24.74, "Open": 24.744074, "Volume": "39292315" }, { "Close": 24.8388, "Date": "2016-10-04T06:59:39.254Z", "High": 24.841346, "Low": 24.81572, "Open": 24.84, "Volume": "20299512" }, { "Close": 24.93696, "Date": "2016-10-03T06:59:39.254Z", "High": 24.938, "Low": 24.936748, "Open": 24.937, "Volume": "32066874" }, { "Close": 25.0333, "Date": "2016-10-02T06:59:39.254Z", "High": 25.03419, "Low": 25.03, "Open": 25.033575, "Volume": "30087601" }, { "Close": 25.67, "Date": "2016-09-29T06:59:39.254Z", "High": 26.17, "Low": 25.41, "Open": 26.113, "Volume": "36948505" }, { "Close": 25.829, "Date": "2016-09-28T06:59:39.254Z", "High": 26.34, "Low": 25.49463, "Open": 26, "Volume": "33037236" }];
    }


    

}